| refundr | R Documentation |
refundr makes functional data analyses
in R more consistent and user friendly
refundr provides:
tidy interface for common fpca methods and funcional regression
plays nice with the tidyfun package for wrangling functional data
Also see vignette("refundr") for a brief introduction.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.